# OPS07-BP03: Use runbooks to perform procedures

## Description

Documented runbooks cho routine procedures.

## Implementation Guidance

- Runbooks for common operations
- Version controlled runbooks
- Regular runbook reviews
- Automation of runbook steps
- Runbook execution tracking

## Risk Level

Medium - Ad-hoc procedures are inconsistent and error-prone.
